@@ -778,14 +778,14 @@ DoInit (int argc, char * argv[], bool & exit)
     return EXIT_FAILURE;
   }
 
-#ifdef __LINUX__
+#ifdef __linux__
   if (!getenv ("ALSA_CONFIG_DIR"))
   {
     static char env[256];
     snprintf (env, sizeof (env), "ALSA_CONFIG_DIR=/usr/share/alsa");
     putenv (env);
   }
-#endif /* __LINUX__ */
+#endif /* __linux__ */
 
 #ifdef _WIN32
   /* Fix laggy sounds on Windows by not using winmm driver. */
@@ -821,11 +821,12 @@ DoInit (int argc, char * argv[], bool & exit)
     return EXIT_FAILURE;
   }
 
-#if 0
-  auto icon = IMG_Load ((GetShareDir () + "icons/hicolor/256x256/apps/blupi.png").c_str ());
+#ifdef __linux__
+  auto icon = IMG_Load (
+    (GetShareDir () + "icons/hicolor/256x256/apps/blupi.png").c_str ());
   SDL_SetWindowIcon (g_window, icon);
   SDL_FreeSurface (icon);
-#endif /* 0 */
+#endif /* __linux__ */
 
   g_renderer = SDL_CreateRenderer (
     g_window, -1, g_rendererType | SDL_RENDERER_TARGETTEXTURE);
