@@ -2,7 +2,7 @@
  * This file is part of the planetblupi source code
  * Copyright (C) 1997, Daniel Roux & EPSITEC SA
  * Copyright (C) 2017-2018, Mathieu Schroeter
- * http://epsitec.ch; http://www.blupi.org; http://github.com/blupi-games
+ * https://epsitec.ch; https://www.blupi.org; https://github.com/blupi-games
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -206,7 +206,7 @@ public:
   bool
   IsFreeCelEmbarque (Point cel, Sint32 rank, Sint32 & action, Point & limit);
   bool
-         IsFreeCelDebarque (Point cel, Sint32 rank, Sint32 & action, Point & limit);
+  IsFreeCelDebarque (Point cel, Sint32 rank, Sint32 & action, Point & limit);
   bool   IsFreeJump (Point cel, Sint32 direct, Sint32 rank, Sint32 & action);
   bool   IsFreeGlisse (Point cel, Sint32 direct, Sint32 rank, Sint32 & action);
   Sint32 DirectSearch (Point cel, Point goal);
@@ -262,7 +262,7 @@ public:
   Sint32 BlupiCreate (
     Point cel, Sint32 action, Sint32 direct, Sint32 perso, Sint32 energy);
   bool   BlupiDelete (Point cel, Sint32 perso = -1);
-  void   BlupiDelete (Sint32 rank);
+  void   BlupiDelete (Sint32 rank, SDL_bool haveSound = SDL_FALSE);
   void   BlupiKill (Sint32 exRank, Point cel, Sint32 type);
   bool   BlupiIfExist (Sint32 rank);
   void   BlupiCheat (Sint32 cheat);
@@ -349,7 +349,7 @@ public:
   // DecIO.cpp
   bool Write (Sint32 rank, bool bUser, Sint32 world, Sint32 time, Sint32 total);
   bool
-       Read (Sint32 rank, bool bUser, Sint32 & world, Sint32 & time, Sint32 & total);
+  Read (Sint32 rank, bool bUser, Sint32 & world, Sint32 & time, Sint32 & total);
   bool FileExist (
     Sint32 rank, bool bUser, Sint32 & world, Sint32 & time, Sint32 & total);
   void Flush ();
