@@ -2,7 +2,7 @@
  * This file is part of the planetblupi source code
  * Copyright (C) 1997, Daniel Roux & EPSITEC SA
  * Copyright (C) 2017-2018, Mathieu Schroeter
- * http://epsitec.ch; http://www.blupi.org; http://github.com/blupi-games
+ * https://epsitec.ch; https://www.blupi.org; https://github.com/blupi-games
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -88,6 +88,8 @@ enum class Language {
   tr    = 6,
   pt    = 7,
   he    = 8,
+  ar    = 9,
+  es    = 10,
   end,
 };
 
@@ -100,7 +102,7 @@ public:
   bool  IsDemoPlaying ();
   Point GetMousePos ();
   void
-              Create (CPixmap * pPixmap, CDecor * pDecor, CSound * pSound, CMovie * pMovie);
+  Create (CPixmap * pPixmap, CDecor * pDecor, CSound * pSound, CMovie * pMovie);
   void        SetFullScreen (bool bFullScreen, double prevScale = 1);
   Sint32      GetWorld ();
   Sint32      GetPhysicalWorld ();
@@ -159,6 +161,8 @@ public:
 
   static void PushUserEvent (Sint32 code, void * data = nullptr);
 
+  Language GetLanguage ();
+
 protected:
   void DrawTextCenter (const char * text, Sint32 x, Sint32 y, Sint32 font = 0);
   bool CreateButtons (Sint32 phase);
@@ -170,7 +174,6 @@ protected:
   bool PlayUp (Point pos);
 
   Language GetStartLanguage ();
-  Language GetLanguage ();
   void     SetLanguage (Language lang = Language::undef);
   void     SetWindowSize (double prevScale, double newScale);
 
@@ -179,7 +182,7 @@ protected:
   void BuildFloor (Point cel, Sint32 insIcon);
   void BuildWater (Point cel, Sint32 insIcon);
   bool
-       BuildDown (Point pos, Uint16 mod, const SDL_Event * event, bool bMix = true);
+  BuildDown (Point pos, Uint16 mod, const SDL_Event * event, bool bMix = true);
   bool BuildMove (Point pos, Uint16 mod, const SDL_Event & event);
 
   void PrivateLibelle ();
@@ -192,7 +195,7 @@ protected:
   bool DemoPlayStart (const std::string * demoFile = nullptr);
   void DemoPlayStop ();
   static void
-       WinToSDLEvent (Uint32 msg, WParam wParam, LParam lParam, SDL_Event & event);
+  WinToSDLEvent (Uint32 msg, WParam wParam, LParam lParam, SDL_Event & event);
   void DemoRecEvent (const SDL_Event & event);
 
 protected:
